==> re-admin-0.17.1.tgz: package/es/components/LoginForm/index.js <==
import { style as _style } from 'antd/lib/icon/style';
import _default from 'antd/lib/icon';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import styles from './styles';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { observer } from 'mobx-react';
import routerStore from '../../stores/routerStore';
import localize from '../../hocs/localize';

import { Form, Input, Submit } from '../Form';

var LoginForm = (_dec = localize('LoginForm'), _dec(_class = observer(_class = (_temp2 = _class2 = function (_Component) {
	_inherits(LoginForm, _Component);

	function LoginForm() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, LoginForm);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = LoginForm.__proto__ || Object.getPrototypeOf(LoginForm)).call.apply(_ref, [this].concat(args))), _this), _this.state = { isValid: true, isPosting: false }, _this._handleValid = function () {
			_this.setState({ isValid: true });
		}, _this._handleInvalid = function () {
			_this.setState({ isValid: false });
		}, _this._handleSubmit = function (data) {
			_this._submit(data);
		}, _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(LoginForm, [{
		key: '_submit',
		value: function () {
			var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee(data) {
				var _context, authStore, defaultLoginRedirection, isOk, ref, url;

				return regeneratorRuntime.wrap(function _callee$(_context2) {
					while (1) {
						switch (_context2.prev = _context2.next) {
							case 0:
								_context = this.context, authStore = _context.authStore, defaultLoginRedirection = _context.appConfig.auth.defaultLoginRedirection;


								this.setState({ isPosting: true });
								_context2.next = 4;
								return authStore.login(data);

							case 4:
								isOk = _context2.sent;

								this.setState({ isPosting: false });

								if (isOk) {
									ref = routerStore.location.query.ref;
									url = ref || defaultLoginRedirection;

									routerStore.history.replace(url);
								}

							case 7:
							case 'end':
								return _context2.stop();
						}
					}
				}, _callee, this);
			}));

			function _submit(_x) {
				return _ref2.apply(this, arguments);
			}

			return _submit;
		}()
	}, {
		key: 'render',
		value: function render() {
			var _state = this.state,
			    isValid = _state.isValid,
			    isPosting = _state.isPosting,
			    _props = this.props,
			    localeStore = _props.localeStore,
			    props = _objectWithoutProperties(_props, ['localeStore']);

			return React.createElement(
				Form,
				_extends({
					onSubmit: this._handleSubmit,
					onValid: this._handleValid,
					onInvalid: this._handleInvalid
				}, props),
				React.createElement(Input, {
					required: true,
					name: 'username',
					prefix: React.createElement(_default, { type: 'user', style: { fontSize: 13 } }),
					placeholder: localeStore.data.usernamePlaceholder
				}),
				React.createElement(Input, {
					required: true,
					name: 'password',
					type: 'password',
					prefix: React.createElement(_default, { type: 'lock', style: { fontSize: 13 } }),
					placeholder: localeStore.data.passwordPlaceholder
				}),
				React.createElement(
					Submit,
					{
						type: 'primary',
						style: styles.button,
						wrapperStyle: styles.buttonWrapper,
						disabled: !isValid,
						loading: isPosting
					},
					localeStore.data.login
				)
			);
		}
	}]);

	return LoginForm;
}(Component), _class2.propTypes = {
	localeStore: PropTypes.object.isRequired
}, _class2.contextTypes = {
	appConfig: PropTypes.object,
	authStore: PropTypes.object
}, _temp2)) || _class) || _class);
export { LoginForm as default };

==> re-admin-0.19.0-0.tgz: package/es/components/LoginForm/index.js <==
import { style as _style } from 'antd/lib/icon/style';
import _default from 'antd/lib/icon';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import styles from './styles';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { observer } from 'mobx-react';
import routerStore from '../../stores/routerStore';
import localize from '../../hocs/localize';

import { Form, Input, Submit } from '../Form';

var LoginForm = (_dec = localize('LoginForm'), _dec(_class = observer(_class = (_temp2 = _class2 = function (_Component) {
	_inherits(LoginForm, _Component);

	function LoginForm() {
		var _ref;

		var _temp, _this, _ret;

		_classCallCheck(this, LoginForm);

		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = LoginForm.__proto__ || Object.getPrototypeOf(LoginForm)).call.apply(_ref, [this].concat(args))), _this), _this.state = { isValid: true, isPosting: false }, _this._handleValid = function () {
			_this.setState({ isValid: true });
		}, _this._handleInvalid = function () {
			_this.setState({ isValid: false });
		}, _this._handleSubmit = function (data) {
			_this._submit(data);
		}, _temp), _possibleConstructorReturn(_this, _ret);
	}

	_createClass(LoginForm, [{
		key: '_submit',
		value: function () {
			var _ref2 = _asyncToGenerator(regeneratorRuntime.mark(function _callee(data) {
				var _context, authStore, defaultLoginRedirection, isOk, ref, url;

				return regeneratorRuntime.wrap(function _callee$(_context2) {
					while (1) {
						switch (_context2.prev = _context2.next) {
							case 0:
								_context = this.context, authStore = _context.authStore, defaultLoginRedirection = _context.appConfig.auth.defaultLoginRedirection;


								this.setState({ isPosting: true });
								_context2.next = 4;
								return authStore.login(data);

							case 4:
								isOk = _context2.sent;

								this.setState({ isPosting: false });

								if (isOk) {
									ref = routerStore.location.query.ref;
									url = ref || defaultLoginRedirection;

									routerStore.history.replace(url);
								}

							case 7:
							case 'end':
								return _context2.stop();
						}
					}
				}, _callee, this);
			}));

			function _submit(_x) {
				return _ref2.apply(this, arguments);
			}

			return _submit;
		}()
	}, {
		key: 'render',
		value: function render() {
			var _state = this.state,
			    isValid = _state.isValid,
			    isPosting = _state.isPosting,
			    _props = this.props,
			    localeStore = _props.localeStore,
			    fields = _props.fields,
			    props = _objectWithoutProperties(_props, ['localeStore', 'fields']);

			return React.createElement(
				Form,
				_extends({
					onSubmit: this._handleSubmit,
					onValid: this._handleValid,
					onInvalid: this._handleInvalid
				}, props),
				fields.length > 0 ? fields.map(function (_ref3, index) {
					var icon = _ref3.icon,
					    restProps = _objectWithoutProperties(_ref3, ['icon']);

					return React.createElement(Input, _extends({
						key: index
					}, restProps, {
						prefix: React.createElement(_default, { type: icon, style: styles.icon })
					}));
				}) : React.createElement(Input, {
					required: true,
					name: 'username',
					prefix: React.createElement(_default, { type: 'user', style: styles.icon }),
					placeholder: localeStore.data.usernamePlaceholder
				}),
				React.createElement(Input, {
					required: true,
					name: 'password',
					type: 'password',
					prefix: React.createElement(_default, { type: 'lock', style: styles.icon }),
					placeholder: localeStore.data.passwordPlaceholder
				}),
				React.createElement(
					Submit,
					{
						type: 'primary',
						style: styles.button,
						wrapperStyle: styles.buttonWrapper,
						disabled: !isValid,
						loading: isPosting
					},
					localeStore.data.login
				)
			);
		}
	}]);

	return LoginForm;
}(Component), _class2.propTypes = {
	localeStore: PropTypes.object.isRequired,
	fields: PropTypes.arrayOf(PropTypes.shape({
		name: PropTypes.string.isRequired,
		icon: PropTypes.string,
		placeholder: PropTypes.string,
		required: PropTypes.bool
	}))
}, _class2.defaultProps = {
	fields: []
}, _class2.contextTypes = {
	appConfig: PropTypes.object,
	authStore: PropTypes.object
}, _temp2)) || _class) || _class);
export { LoginForm as default };
